CREATE TABLE KSIAZKA
( KSIAZKA_ID INT
, ISBN VARCHAR2(20)
, TYTUL VARCHAR2(300)
, AUTOR VARCHAR2(200)
, ROK_WYDANIA NUMBER(4)
, CENA NUMBER(10,2)
, CONSTRAINT KSIAZKA_PK PRIMARY KEY (KSIAZKA_ID)
, CONSTRAINT KSIAZKA_UK_ISBN UNIQUE (ISBN)
);

CREATE TABLE EGZEMPLARZ
( EGZEMPLARZ_ID INT
, SYGNATURA CHAR(8)
, KSIAZKA_ID INT
, CONSTRAINT EGZEMPLARZ_PK PRIMARY KEY (EGZEMPLARZ_ID)
, CONSTRAINT EGZEMPLARZ_UK_SYGNATURA UNIQUE (SYGNATURA)
, CONSTRAINT EGZEMPLARZ_FK FOREIGN KEY (KSIAZKA_ID) REFERENCES KSIAZKA (KSIAZKA_ID) ON DELETE CASCADE
);

CREATE TABLE CZYTELNIK
( CZYTELNIK_ID INT
, PESEL CHAR(11)
, NAZWISKO VARCHAR2(30)
, MIASTO VARCHAR(30)
, DATA_URODZENIA DATE
, CONSTRAINT CZYTELNIK_PK PRIMARY KEY (CZYTELNIK_ID)
, CONSTRAINT CZYTELNIK_UK_PESEL UNIQUE (PESEL)
);

CREATE TABLE WYPOZYCZENIE
( WYPOZYCZENIE_ID INT
, CZYTELNIK_ID INT
, EGZEMPLARZ_ID INT
, DATA DATE
, LICZBA_DNI NUMBER(3)
, CONSTRAINT WYPOZYCZENIE_PK PRIMARY KEY (WYPOZYCZENIE_ID)
, CONSTRAINT WYPOZYCZENIE_FK_CZYTELNIK FOREIGN KEY (CZYTELNIK_ID) REFERENCES CZYTELNIK (CZYTELNIK_ID) ON DELETE CASCADE
, CONSTRAINT WYPOZYCZENIE_FK_EGZEMPLARZ FOREIGN KEY (EGZEMPLARZ_ID) REFERENCES EGZEMPLARZ (EGZEMPLARZ_ID) ON DELETE CASCADE
);

INSERT INTO KSIAZKA (KSIAZKA_ID,ISBN,TYTUL,AUTOR,ROK_WYDANIA,CENA) VALUES(1,'83-246-0279-8','Microsoft Access. Podrcznik administratora','Helen Feddema',2006,69);
INSERT INTO KSIAZKA (KSIAZKA_ID,ISBN,TYTUL,AUTOR,ROK_WYDANIA,CENA) VALUES(2,'83-246-0653-X','SQL Server 2005. Programowanie. Od podstaw','Robert Vieira',2007,97);
INSERT INTO KSIAZKA (KSIAZKA_ID,ISBN,TYTUL,AUTOR,ROK_WYDANIA,CENA) VALUES(3,'978-83-246-0549-1','SQL Server 2005. Wycinij wszystko','Eric L. Brown',2007,57);
INSERT INTO KSIAZKA (KSIAZKA_ID,ISBN,TYTUL,AUTOR,ROK_WYDANIA,CENA) VALUES(4,'978-83-246-1258-1','PHP, MySQL i MVC. Tworzenie witryn WWW opartych na bazie danych','Wodzimierz Gajda',2010,79);
INSERT INTO KSIAZKA (KSIAZKA_ID,ISBN,TYTUL,AUTOR,ROK_WYDANIA,CENA) VALUES(5,'978-83-246-2060-9','Access 2007 PL. Seria praktyk','Andrew Unsworth',2009,39);
INSERT INTO KSIAZKA (KSIAZKA_ID,ISBN,TYTUL,AUTOR,ROK_WYDANIA,CENA) VALUES(6,'978-83-246-2188-0','Czysty kod. Podrcznik dobrego programisty','Robert C. Martin',2010,67);

INSERT INTO EGZEMPLARZ (EGZEMPLARZ_ID,KSIAZKA_ID,SYGNATURA) VALUES(1,5,'S0001');
INSERT INTO EGZEMPLARZ (EGZEMPLARZ_ID,KSIAZKA_ID,SYGNATURA) VALUES(2,5,'S0002');
INSERT INTO EGZEMPLARZ (EGZEMPLARZ_ID,KSIAZKA_ID,SYGNATURA) VALUES(3,1,'S0003');
INSERT INTO EGZEMPLARZ (EGZEMPLARZ_ID,KSIAZKA_ID,SYGNATURA) VALUES(4,1,'S0004');
INSERT INTO EGZEMPLARZ (EGZEMPLARZ_ID,KSIAZKA_ID,SYGNATURA) VALUES(5,1,'S0005');
--INSERT INTO EGZEMPLARZ (EGZEMPLARZ_ID,KSIAZKA_ID,SYGNATURA) VALUES(6,2,'S0006');
INSERT INTO EGZEMPLARZ (EGZEMPLARZ_ID,KSIAZKA_ID,SYGNATURA) VALUES(7,3,'S0007');
INSERT INTO EGZEMPLARZ (EGZEMPLARZ_ID,KSIAZKA_ID,SYGNATURA) VALUES(8,3,'S0008');
INSERT INTO EGZEMPLARZ (EGZEMPLARZ_ID,KSIAZKA_ID,SYGNATURA) VALUES(9,3,'S0009');
INSERT INTO EGZEMPLARZ (EGZEMPLARZ_ID,KSIAZKA_ID,SYGNATURA) VALUES(10,3,'S0010');
INSERT INTO EGZEMPLARZ (EGZEMPLARZ_ID,KSIAZKA_ID,SYGNATURA) VALUES(11,6,'S0011');
INSERT INTO EGZEMPLARZ (EGZEMPLARZ_ID,KSIAZKA_ID,SYGNATURA) VALUES(12,6,'S0012');
INSERT INTO EGZEMPLARZ (EGZEMPLARZ_ID,KSIAZKA_ID,SYGNATURA) VALUES(13,4,'S0013');
INSERT INTO EGZEMPLARZ (EGZEMPLARZ_ID,KSIAZKA_ID,SYGNATURA) VALUES(14,4,'S0014');
INSERT INTO EGZEMPLARZ (EGZEMPLARZ_ID,KSIAZKA_ID,SYGNATURA) VALUES(15,4,'S0015');

INSERT INTO CZYTELNIK (CZYTELNIK_ID,PESEL,NAZWISKO,MIASTO,DATA_URODZENIA) VALUES(1,'55101011111','Kowalski','Wrocaw','1955-10-10');
INSERT INTO CZYTELNIK (CZYTELNIK_ID,PESEL,NAZWISKO,MIASTO,DATA_URODZENIA) VALUES(2,'60101033333','Maliniak','Wrocaw','1960-10-10');
INSERT INTO CZYTELNIK (CZYTELNIK_ID,PESEL,NAZWISKO,MIASTO,DATA_URODZENIA) VALUES(3,'65120122222','Nowak','Warszawa','1965-12-01');

INSERT INTO WYPOZYCZENIE (WYPOZYCZENIE_ID,CZYTELNIK_ID,EGZEMPLARZ_ID,DATA,LICZBA_DNI) VALUES(1,1,3,'2011-02-01',12);
INSERT INTO WYPOZYCZENIE (WYPOZYCZENIE_ID,CZYTELNIK_ID,EGZEMPLARZ_ID,DATA,LICZBA_DNI) VALUES(2,1,4,'2011-01-05',20);
INSERT INTO WYPOZYCZENIE (WYPOZYCZENIE_ID,CZYTELNIK_ID,EGZEMPLARZ_ID,DATA,LICZBA_DNI) VALUES(3,1,15,'2011-01-21',45);
INSERT INTO WYPOZYCZENIE (WYPOZYCZENIE_ID,CZYTELNIK_ID,EGZEMPLARZ_ID,DATA,LICZBA_DNI) VALUES(4,2,8,'2011-01-13',7);
INSERT INTO WYPOZYCZENIE (WYPOZYCZENIE_ID,CZYTELNIK_ID,EGZEMPLARZ_ID,DATA,LICZBA_DNI) VALUES(5,3,4,'2011-02-01',14);
INSERT INTO WYPOZYCZENIE (WYPOZYCZENIE_ID,CZYTELNIK_ID,EGZEMPLARZ_ID,DATA,LICZBA_DNI) VALUES(6,3,12,'2011-02-02',10);
